@@ -215,8 +215,12 @@ def render(ctx, name, args):
 @templates.command(context_settings=dict(ignore_unknown_options=True))
 @click.argument('name', nargs=1)
 @click.argument('args', nargs=-1, type=click.UNPROCESSED)
-@click.option('-o', '--output', 'output_file', help='File to write results to (otherwise output to console)')
-@click.option('-l', '--limit', 'limit', default=0, help='Limit the number of rows returned', show_default=True)
+@click.option(
+    '-o', '--output', 'output_file', help='File to write results to (otherwise output to console)'
+)
+@click.option(
+    '-l', '--limit', 'limit', default=0, help='Limit the number of rows returned', show_default=True
+)
 @click.option(
     '-n',
     '--nowait',
