@@ -107,6 +107,8 @@ def run(
         creds[upload_name] = {}
         creds[upload_name]['aws_access_key_id'] = cred['aws_access_key_id']
         creds[upload_name]['aws_secret_access_key'] = cred['aws_secret_access_key']
+        if 'region' in cred:
+            creds[upload_name]['region'] = cred['region']
 
     if not project_name:
         abort("You must specify PROJECT_NAME")
