@@ -102,20 +102,27 @@ def find_aws_credentials(profile):
     if not profile:
         access_key = None
         secret_key = None
+        region = None
         token = ''
         credentials = botocore.session.get_session().get_credentials()
         if credentials:
             access_key = credentials.access_key
             secret_key = credentials.secret_key
+            region = credentials.region
             token = getattr(credentials, 'token') or ''
         if not access_key or not secret_key:
             raise RuntimeError("No Default AWS profile set")
 
-        return {
+        ret = {
             "aws_access_key_id": access_key,
             "aws_secret_access_key": secret_key,
-            "aws_session_token": token,
+            "aws_session_token": token
         }
+        # only add the region if it is defined
+        if region:
+            ret['region'] = region
+
+        return ret
 
     folder = os.path.join(os.path.expanduser("~"), ".aws")
     filename = os.path.join(folder, 'credentials')
@@ -129,7 +136,6 @@ def find_aws_credentials(profile):
             ret[key] = cfg[profile][key]
     return ret
 
-
 def abort(reason, code=1):
     """
     exit with non-zero exit code and write reason for error to stderr.
